@@ -70,7 +70,5 @@ class DAQ(DeviceBase):
     """Description of DAQ system"""
 
     device_name: str = Field(..., title="PC device name")
-    update_frequency: float = Field(
-        ..., title="DAQ update frequency (Hz)", units="Hz"
-    )
+    update_frequency: float = Field(..., title="DAQ update frequency (Hz)", units="Hz")
     number_active_channels: int = Field(..., title="Number of active channels")
