@@ -95,30 +95,20 @@ class Stream(AindModel):
 class EphysSession(AindCoreModel):
     """Description of an ephys recording session"""
 
-    schema_version: str = Field(
-        "0.2.1", description="schema version", title="Version", const=True
-    )
+    schema_version: str = Field("0.2.1", description="schema version", title="Version", const=True)
     experimenter_full_name: str = Field(
-        ...,
-        description="First and last name of the experimenter.",
-        title="Experimenter full name",
+        ..., description="First and last name of the experimenter.", title="Experimenter full name",
     )
     session_start_time: datetime = Field(..., title="Session start time")
     session_end_time: datetime = Field(..., title="Session end time")
     subject_id: int = Field(..., title="Subject ID")
     session_type: SessionType = Field(..., title="Session type")
-    session_description: Optional[str] = Field(
-        None, title="Session description"
-    )
-    stimulus_protocol_id: Optional[str] = Field(
-        None, title="Stimulus protocol ID"
-    )
+    session_description: Optional[str] = Field(None, title="Session description")
+    stimulus_protocol_id: Optional[str] = Field(None, title="Stimulus protocol ID")
     iacuc_protocol: Optional[str] = Field(None, title="IACUC protocol")
     rig_id: str = Field(..., title="Rig ID")
     expected_data_streams: Optional[List[ExpectedDataStream]] = None
-    probe_streams: List[Stream] = Field(
-        ..., title="Probe streams", unique_items=True
-    )
+    probe_streams: List[Stream] = Field(..., title="Probe streams", unique_items=True)
     ccf_coordinate_transform: Optional[str] = Field(
         None,
         description="Path to file that details the CCF-to-lab coordinate transform.",
