@@ -31,9 +31,7 @@ class Camera(Device):
     angle_yaw: float = Field(..., title="Angle yaw (deg)")
     angle_roll: float = Field(..., title="Angle roll (deg)")
     recording_software: Optional[str] = Field(None, title="Recording software")
-    recording_software_version: Optional[str] = Field(
-        None, title="Recording software version"
-    )
+    recording_software_version: Optional[str] = Field(None, title="Recording software version")
 
 
 class CameraType(Enum):
@@ -72,9 +70,7 @@ class Detector(Device):
     """Description of a generic detector"""
 
     name: Optional[str] = Field(
-        None,
-        description="Brief name to identify detector to match with session information",
-        title="Name",
+        None, description="Brief name to identify detector to match with session information", title="Name",
     )
     type: CameraType = Field(..., title="Camera Type")
     data_interface: DataInterface = Field(..., title="Data interface")
@@ -103,9 +99,7 @@ class Filter(Device):
     size: Optional[FilterSize] = Field(None, title="Size (mm)")
     cut_off_frequency: Optional[int] = Field(None, title="Cut off frequency")
     cut_on_frequency: Optional[int] = Field(None, title="Cut on frequency")
-    description: Optional[str] = Field(
-        None, description="Where/how filter is being used", title="Description"
-    )
+    description: Optional[str] = Field(None, description="Where/how filter is being used", title="Description")
 
 
 class LaserName(Enum):
@@ -135,15 +129,9 @@ class Laser(Device):
     wavelength: int = Field(..., title="Wavelength (nm)")
     maximum_power: float = Field(..., title="Maximum power (mW)")
     coupling: Optional[Coupling] = Field(None, title="Coupling")
-    coupling_efficiency: Optional[float] = Field(
-        None, title="Coupling efficiency (percent)"
-    )
-    calibration_data: Optional[str] = Field(
-        None, description="path to calibration data", title="Calibration data"
-    )
-    calibration_date: Optional[datetime] = Field(
-        None, title="Calibration date"
-    )
+    coupling_efficiency: Optional[float] = Field(None, title="Coupling efficiency (percent)")
+    calibration_data: Optional[str] = Field(None, description="path to calibration data", title="Calibration data")
+    calibration_date: Optional[datetime] = Field(None, title="Calibration date")
 
 
 class LensSize(Enum):
@@ -158,9 +146,7 @@ class Lens(Device):
 
     focal_length: Optional[float] = Field(None, title="Focal length (mm)")
     size: Optional[LensSize] = Field(None, title="Size (inches)")
-    optimized_wavelength_range: Optional[str] = Field(
-        None, title="Optimized wavelength range (nm)"
-    )
+    optimized_wavelength_range: Optional[str] = Field(None, title="Optimized wavelength range (nm)")
     notes: Optional[str] = Field(None, title="Notes")
 
 
@@ -178,51 +164,28 @@ class Patch(Device):
     name: PatchName = Field(..., title="Patch Name")
     core_diameter: float = Field(..., title="Core diameter (um)")
     numerical_aperture: float = Field(..., title="Numerical aperture")
-    photobleaching_date: Optional[date] = Field(
-        None, title="Photobleaching date"
-    )
+    photobleaching_date: Optional[date] = Field(None, title="Photobleaching date")
 
 
 class OphysRig(AindCoreModel):
     """Description of an optical physiology rig"""
 
     schema_version: str = Field(
-        "0.2.0",
-        description="schema version",
-        title="Schema Version",
-        const=True,
-    )
-    rig_id: str = Field(
-        ..., description="room number_stim apparatus_version", title="Rig ID"
+        "0.2.0", description="schema version", title="Schema Version", const=True,
     )
+    rig_id: str = Field(..., description="room number_stim apparatus_version", title="Rig ID")
     rig_location: Optional[str] = Field(None, title="Rig location")
-    temperature_control: Optional[bool] = Field(
-        None, title="Temperature control"
-    )
+    temperature_control: Optional[bool] = Field(None, title="Temperature control")
     humidity_control: Optional[bool] = Field(None, title="Humidity control")
     vibration_control: Optional[bool] = Field(None, title="Vibration control")
-    patch_cords: List[Patch] = Field(
-        ..., title="Patch cords", unique_items=True
-    )
-    cameras: Optional[List[Camera]] = Field(
-        None, title="Cameras", unique_items=True
-    )
+    patch_cords: List[Patch] = Field(..., title="Patch cords", unique_items=True)
+    cameras: Optional[List[Camera]] = Field(None, title="Cameras", unique_items=True)
     lasers: List[Laser] = Field(..., title="Lasers", unique_items=True)
-    detectors: Optional[List[Detector]] = Field(
-        None, title="Detectors", unique_items=True
-    )
-    filters: Optional[List[Filter]] = Field(
-        None, title="Filters", unique_items=True
-    )
-    lenses: Optional[List[Lens]] = Field(
-        None, title="Lenses", unique_items=True
-    )
-    additional_devices: Optional[List[Device]] = Field(
-        None, title="Additional devices", unique_items=True
-    )
+    detectors: Optional[List[Detector]] = Field(None, title="Detectors", unique_items=True)
+    filters: Optional[List[Filter]] = Field(None, title="Filters", unique_items=True)
+    lenses: Optional[List[Lens]] = Field(None, title="Lenses", unique_items=True)
+    additional_devices: Optional[List[Device]] = Field(None, title="Additional devices", unique_items=True)
     light_path_diagram: Optional[str] = Field(
-        None,
-        description="Path to diagram of the light path.",
-        title="Light path diagram",
+        None, description="Path to diagram of the light path.", title="Light path diagram",
     )
     notes: Optional[str] = Field(None, title="Notes")
