@@ -38,14 +38,10 @@ class LightCycle(AindModel):
     """Description of vivarium light cycle times"""
 
     lights_on_time: time = Field(
-        ...,
-        description="Time in UTC that lights were turned on",
-        title="Lights on time",
+        ..., description="Time in UTC that lights were turned on", title="Lights on time",
     )
     lights_off_time: time = Field(
-        ...,
-        description="Time in UTC that lights were turned off",
-        title="Lights off time",
+        ..., description="Time in UTC that lights were turned off", title="Lights off time",
     )
 
 
@@ -77,9 +73,7 @@ class MgiAlleleId(AindModel):
 class Subject(AindCoreModel):
     """Description of a subject of data collection"""
 
-    schema_version: str = Field(
-        "0.2.2", description="schema version", title="Version", const=True
-    )
+    schema_version: str = Field("0.2.2", description="schema version", title="Version", const=True)
     species: Species = Field(..., title="Species")
     subject_id: str = Field(
         ...,
@@ -89,30 +83,18 @@ class Subject(AindCoreModel):
     sex: Sex = Field(..., title="Sex")
     date_of_birth: date = Field(..., title="Date of birth")
     genotype: str = Field(
-        ...,
-        description="Genotype of the animal providing both alleles",
-        title="Genotype",
-    )
-    mgi_allele_ids: Optional[List[MgiAlleleId]] = Field(
-        None, title="MGI allele ids"
-    )
-    background_strain: Optional[BackgroundStrain] = Field(
-        None, title="Background strain"
+        ..., description="Genotype of the animal providing both alleles", title="Genotype",
     )
+    mgi_allele_ids: Optional[List[MgiAlleleId]] = Field(None, title="MGI allele ids")
+    background_strain: Optional[BackgroundStrain] = Field(None, title="Background strain")
     source: Optional[str] = Field(
-        None,
-        description="If the subject was not bred in house, where was it acquired from.",
-        title="Source",
+        None, description="If the subject was not bred in house, where was it acquired from.", title="Source",
     )
     rrid: Optional[str] = Field(
-        None,
-        description="RRID of mouse if acquired from supplier",
-        title="RRID",
+        None, description="RRID of mouse if acquired from supplier", title="RRID",
     )
     restrictions: Optional[str] = Field(
-        None,
-        description="Any restrictions on use or publishing based on subject source",
-        title="Restrictions",
+        None, description="Any restrictions on use or publishing based on subject source", title="Restrictions",
     )
     breeding_group: Optional[str] = Field(None, title="Breeding Group")
     maternal_id: Optional[str] = Field(None, title="Maternal specimen ID")
@@ -120,10 +102,6 @@ class Subject(AindCoreModel):
     paternal_id: Optional[str] = Field(None, title="Paternal specimen ID")
     paternal_genotype: Optional[str] = Field(None, title="Paternal genotype")
     light_cycle: Optional[LightCycle] = Field(None, title="Light cycle")
-    home_cage_enrichment: Optional[HomeCageEnrichment] = Field(
-        None, title="Home cage enrichment"
-    )
-    wellness_reports: Optional[List[WellnessReport]] = Field(
-        None, title="Wellness Report"
-    )
+    home_cage_enrichment: Optional[HomeCageEnrichment] = Field(None, title="Home cage enrichment")
+    wellness_reports: Optional[List[WellnessReport]] = Field(None, title="Wellness Report")
     notes: Optional[str] = Field(None, title="Notes")
