@@ -4,12 +4,7 @@ import datetime
 import json
 import unittest
 
-from aind_data_schema.data_description import (
-    DataDescription,
-    DerivedDataDescription,
-    Funding,
-    RawDataDescription,
-)
+from aind_data_schema.data_description import DataDescription, DerivedDataDescription, Funding, RawDataDescription
 
 
 class DataDescriptionTest(unittest.TestCase):
@@ -17,9 +12,7 @@ class DataDescriptionTest(unittest.TestCase):
 
     BAD_NAME = "fizzbuzz"
     BASIC_NAME = "ecephys_1234_3033-12-21_04-22-11"
-    DERIVED_NAME = (
-        "ecephys_1234_3033-12-21_04-22-11_spikesorted-ks25_2022-10-12_23-23-11"
-    )
+    DERIVED_NAME = "ecephys_1234_3033-12-21_04-22-11_spikesorted-ks25_2022-10-12_23-23-11"
 
     def test_from_name(self):
         """test the from_name methods"""
@@ -38,42 +31,27 @@ class DataDescriptionTest(unittest.TestCase):
 
         with self.assertRaises(ValueError):
             DataDescription.from_name(
-                name=self.BAD_NAME,
-                institution="AIND",
-                data_level="raw data",
-                funding_source=[f],
+                name=self.BAD_NAME, institution="AIND", data_level="raw data", funding_source=[f],
             )
 
-        rd = RawDataDescription.from_name(
-            name=self.BASIC_NAME, institution="AIND", funding_source=[f]
-        )
+        rd = RawDataDescription.from_name(name=self.BASIC_NAME, institution="AIND", funding_source=[f])
         assert rd.name == self.BASIC_NAME
         assert rd.data_level.value == "raw data"
 
         with self.assertRaises(ValueError):
             RawDataDescription.from_name(
-                name=self.BAD_NAME,
-                institution="AIND",
-                data_level="raw data",
-                funding_source=[f],
+                name=self.BAD_NAME, institution="AIND", data_level="raw data", funding_source=[f],
             )
 
         dd = DerivedDataDescription.from_name(
-            name=self.DERIVED_NAME,
-            institution="AIND",
-            funding_source=[f],
-            modality="SmartSPIM",
-            subject_id="12345",
+            name=self.DERIVED_NAME, institution="AIND", funding_source=[f], modality="SmartSPIM", subject_id="12345",
         )
         assert dd.name == self.DERIVED_NAME
         assert dd.data_level.value == "derived data"
 
         with self.assertRaises(ValueError):
             DerivedDataDescription.from_name(
-                name=self.BAD_NAME,
-                institution="AIND",
-                data_level="raw data",
-                funding_source=[f],
+                name=self.BAD_NAME, institution="AIND", data_level="raw data", funding_source=[f],
             )
 
     def test_from_data_description(self):
