@@ -6,13 +6,8 @@ import unittest
 from pydantic import ValidationError
 
 from aind_data_schema import Procedures
-from aind_data_schema.procedures import (
-    FiberImplant,
-    InjectionMaterial,
-    NanojectInjection,
-    OphysProbe,
-    RetroOrbitalInjection,
-)
+from aind_data_schema.procedures import (FiberImplant, InjectionMaterial, NanojectInjection, OphysProbe,
+                                         RetroOrbitalInjection)
 
 
 class ProceduresTests(unittest.TestCase):
@@ -38,13 +33,7 @@ class ProceduresTests(unittest.TestCase):
                     end_date=now,
                     experimenter_full_name="tom",
                     protocol_id="134",
-                    injection_materials=[
-                        InjectionMaterial(
-                            name="abc",
-                            titer="5.46E13",
-                            prep_lot_number="CT323",
-                        )
-                    ],
+                    injection_materials=[InjectionMaterial(name="abc", titer="5.46E13", prep_lot_number="CT323",)],
                     injection_volume=1,
                     injection_eye="Left",
                     injection_duration=1,
@@ -55,13 +44,7 @@ class ProceduresTests(unittest.TestCase):
                     end_date=now,
                     experimenter_full_name="betsy",
                     protocol_id="bca",
-                    injection_materials=[
-                        InjectionMaterial(
-                            name="abc",
-                            titer="5.46E13",
-                            prep_lot_number="CT323",
-                        )
-                    ],
+                    injection_materials=[InjectionMaterial(name="abc", titer="5.46E13", prep_lot_number="CT323",)],
                     injection_duration=1,
                     injection_coordinate_ml=1,
                     injection_coordinate_ap=1,
